@@ -4,18 +4,17 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef BLUETOOTH_H
-#define BLUETOOTH_H
+#pragma once
 
-#include <KQuickAddons/ConfigModule>
+#include <KQuickConfigModule>
 #include <QObject>
 
-class Bluetooth : public KQuickAddons::ConfigModule
+class Bluetooth : public KQuickConfigModule
 {
     Q_OBJECT
 
 public:
-    Bluetooth(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+    Bluetooth(QObject *parent, const KPluginMetaData &data);
 
     Q_INVOKABLE void runWizard();
     Q_INVOKABLE void runSendFile(const QString &ubi);
@@ -36,5 +35,3 @@ Q_SIGNALS:
 private:
     void checkNetworkInternal(const QString &service, const QString &address);
 };
-
-#endif // BLUETOOTHKCM_H
